@@ -428,7 +428,12 @@ class Batch(object):
                     filter_name, output_ext = filter_opts
                     filter_args = {}
                 else:
-                    filter_name, output_ext, filter_args = filter_opts
+                    filter_name = filter_opts[0]
+                    output_ext = filter_opts[1]
+                    if len(filter_opts) == 3 and isinstance(filter_opts[2] , dict):
+                        filter_args = filter_opts[2]
+                    else:
+                        filter_args = filter_opts[2:]
 
                 filter_doc_hash = hash_for_document(template_doc.h, filter_name, output_ext, filter_args)
                 result_filename = "%s.%s" % (os.path.splitext(doc.canonical_filename)[0], output_ext)
