@@ -20,4 +20,5 @@ def do_weasyprint(input_filepath, output_filepath, output_ext, filter_args):
     HTML(input_filepath).write_pdf(output_filepath)
 
 def do_pandoc(input_filepath, output_filepath, output_ext, filter_args):
-    subprocess.run(['/opt/local/bin/pandoc', input_filepath, '-o', output_filepath], capture_output=True, check=True)
+    subprocess.run(['/opt/local/bin/pandoc', input_filepath, '-o', output_filepath] + filter_args,
+            capture_output=True, check=True)
